@@ -3,6 +3,8 @@ import pytest
 
 from xapiparser import parse
 from xapiparser.cli import main
+from xapiparser.exception import ParseError
+from xapiparser.exception import UnsupportedError
 
 
 @pytest.fixture
@@ -15,7 +17,7 @@ def test_main(strip_whitespace):
 
 
 def test_simple(strip_whitespace):
-    expression = 'xConfiguration Conference Encryption Mode'
+    cmd = 'xConfiguration Conference Encryption Mode'
     xapi = """
         <Configuration>
             <Conference>
@@ -26,12 +28,12 @@ def test_simple(strip_whitespace):
         </Configuration>
         """
     expected = etree.XML(xapi, parser=strip_whitespace)
-    parsed = parse(expression)
+    parsed = parse(cmd)
     assert etree.tostring(expected) == etree.tostring(parsed)
 
 
 def test_tag_val(strip_whitespace):
-    expression = 'xCommand Audio Volume Set Level: 50'
+    cmd = 'xCommand Audio Volume Set Level: 50'
     xapi = """
     <Command>
         <Audio>
@@ -44,12 +46,12 @@ def test_tag_val(strip_whitespace):
     </Command>
     """
     expected = etree.XML(xapi, parser=strip_whitespace)
-    parsed = parse(expression)
+    parsed = parse(cmd)
     assert etree.tostring(expected) == etree.tostring(parsed)
 
 
 def test_multiple_key_value(strip_whitespace):
-    expression = 'xCommand Dial Number: "12345" Protocol: H323'
+    cmd = 'xCommand Dial Number: "12345" Protocol: H323'
     xapi = """
     <Command>
         <Dial>
@@ -59,12 +61,12 @@ def test_multiple_key_value(strip_whitespace):
     </Command>
     """
     expected = etree.XML(xapi, parser=strip_whitespace)
-    parsed = parse(expression)
+    parsed = parse(cmd)
     assert etree.tostring(expected) == etree.tostring(parsed)
 
 
 def test_item_attribute(strip_whitespace):
-    expression = "xConfiguration Video Input Connector 2 InputSourceType: camera"
+    cmd = "xConfiguration Video Input Connector 2 InputSourceType: camera"
     xapi = """
     <Configuration>
         <Video>
@@ -77,12 +79,12 @@ def test_item_attribute(strip_whitespace):
     </Configuration>
     """
     expected = etree.XML(xapi, parser=strip_whitespace)
-    parsed = parse(expression)
+    parsed = parse(cmd)
     assert etree.tostring(expected) == etree.tostring(parsed)
 
 
 def test_attribute_suffixes(strip_whitespace):
-    expression = 'xCommand HttpFeedback Register FeedbackSlot: 2 ServerUrl: https://status.oops.com/ Format: JSON ' \
+    cmd = 'xCommand HttpFeedback Register FeedbackSlot: 2 ServerUrl: https://status.oops.com/ Format: JSON ' \
                  'Expression[1]: /Event/UserInterface/Message/Prompt/Response ' \
                  'Expression[2]: /Event/UserInterface/Message/TextInput/Response/text ' \
                  'Expression[3]: /Event/CallDisconnect'
@@ -101,5 +103,36 @@ def test_attribute_suffixes(strip_whitespace):
     </Command>
     """
     expected = etree.XML(xapi, parser=strip_whitespace)
-    parsed = parse(expression)
+    parsed = parse(cmd)
     assert etree.tostring(expected) == etree.tostring(parsed)
+
+
+def test_whitespace_attribute(strip_whitespace):
+    cmd = "xConfiguration NetworkServices SNMP SystemContact: '43.51, 1.81'"
+    xapi = """
+    <Configuration>
+        <NetworkServices>
+            <SNMP>
+                <SystemContact>43.51, 1.81</SystemContact>
+            </SNMP>
+        </NetworkServices>
+    </Configuration>
+    """
+    expected = etree.XML(xapi, parser=strip_whitespace)
+    parsed = parse(cmd)
+    assert etree.tostring(expected) == etree.tostring(parsed)
+
+
+def test_not_implemented_error():
+    with pytest.raises(NotImplementedError):
+        parse('xgetxml /Configuration/Video/Layout/Scaling | resultId="mytag _ 2"')
+
+
+def test_unsupported__error_ssh_only_cmd():
+    with pytest.raises(UnsupportedError):
+        parse("systemtools license list")
+
+
+def test_parse_error():
+    with pytest.raises(ParseError):
+        parse("not valid xapi ssh cmd")
